/**
 * \file
 *
 */

/* Errors */
/** \brief Tool error message */
#define TOOL_XMLPARSE_ERRMSG                "Parse error in XML file"

/* Error codes (50 ->69) */
/** \brief Tool error code */
#define TOOL_UNKNOWN_ERRCODE                1            
/** \brief Tool error code */
#define TOOL_EXTERNAL_ERRCODE               2
/** \brief Tool error code */
#define TOOL_XMLPARSE_ERRCODE               50


extern char * global_errmsg;

/**
 * \fn      int toolRunProgram(char **args);
 * \brief   Execute a program
 *
 * \param   args Arguments array. First entry must be program name, an last one must be NULL
 *
 * \return  0 if successful
 * \return  1+ if error occurs
 */
int toolRunProgram(char **args);

/**
 * \fn      int toolLoadFile(int fd, char **buf);
 * \brief   Load an opened file in memory
 *
 * \param   fd File descriptor
 * \param   buf Address of the buffer where the content of the file will be loaded to
 *
 * \return  0 if successful
 * \return  1+ if error occurs
 */
int toolLoadFile(int fd, char **buf);

/**
 * \fn      int toolGetTag(char *buf, char *tag, int nb, char ** result);
 * \brief   Find a complete XML tag in a string
 *
 * \param   buf Buffer containing the source string
 * \param   tag Tag to be retrieved
 * \param   nb Occurence number of tag to be retrieved
 * \param   result Address of the pointer where the result will be stored
 *
 * \return  0 if successful
 * \return  1+ if error occurs
 */
int toolGetTag(char *buf, char *tag, int nb, char ** result);
