/**
 * \file
 * \brief IPv4 SCOP Transport module (SCOP Interface)
 */

/* TODO: error checking */

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <arpa/inet.h>

#include <err.h>
#include <errno.h>

#include "scop.h"

/** \brief IPv4 socket descriptor */
int scop_ipv4_socket;

int scopTransportQuit()
{
  close(scop_ipv4_socket);
  return 0; /* FIXME */
}

int scopTransportInit()
{
  struct sockaddr_in sa;
  struct hostent *hp;
  int result;
  unsigned int sa_size = sizeof(struct sockaddr_in);

#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  /* create ipv4 TCP socket */
  scop_ipv4_socket = socket(PF_INET, SOCK_STREAM, 0);
  if(scop_ipv4_socket == -1)
    {
      warnx("%s(): %s", __FUNCTION__, strerror(errno));
      return SCOP_EXTERNAL_ERRCODE;
    }

  /* check ip address */
  memset(&sa, 0, sizeof(struct sockaddr_in));
  hp = gethostbyname(SCOP_SERVER_ADDR);
  if(hp == NULL)
    {
      warnx("%s(): %s", __FUNCTION__, strerror(h_errno));
      return SCOP_EXTERNAL_ERRCODE;
    }

  sa.sin_family = AF_INET;
  sa.sin_addr.s_addr = inet_addr(SCOP_SERVER_ADDR);
  sa.sin_port = htons(SCOP_SERVER_PORT);

  /* bind socket to ip adress and port */
  result = bind(scop_ipv4_socket, (struct sockaddr*)&sa, sizeof(struct sockaddr_in));
  if(result == -1)
    {
      warnx("%s(): %s", __FUNCTION__, strerror(errno));
      return SCOP_EXTERNAL_ERRCODE;
    }

  /* wait for connections */
  result = listen(scop_ipv4_socket,1);
  if(result == -1)
    {
      warnx("%s(): %s", __FUNCTION__, strerror(errno));
      return SCOP_EXTERNAL_ERRCODE;
    }

  /* accept connection request */
  result = accept(scop_ipv4_socket, (struct sockaddr*)&sa, &sa_size);
  if(result == -1)
    {
      warnx("%s(): %s", __FUNCTION__, strerror(errno));
      return SCOP_EXTERNAL_ERRCODE;
    }

  /* close connection socket */
  close(scop_ipv4_socket);
  scop_ipv4_socket = result;

  return 0;
}

void scopTransportRead(char * buffer, int len)
{
  int i;

#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  /* get bytes one by one from the socket */
  for(i=0; i<len; i++)
    {
      while(read(scop_ipv4_socket, &buffer[i], 1) != 1);
    }

  return;
}

void scopTransportSend(char * buffer, int len)
{
#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  /* send message through the socket */
  write(scop_ipv4_socket, buffer, len);

  /* append end-of-message magic byte (0x00) */
/*   write(scop_ipv4_socket, "", 1); */
  
  return;
}

void scopTransportSynchro(char * magic)
{
  int i;
  char c;

#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  for(i=0; i<strlen(magic);)
    {
      int ret;

      /* read next char */
      if((ret=read(scop_ipv4_socket, &c, 1)) != 1) 
	{
#ifdef DEBUG
  printf("DEBUG: %s() read return :%d\n",__FUNCTION__, ret);
#endif
  scopTransportQuit();
  scopTransportInit();
	}
      /* check if this char matches magic's current char */
      if(c == magic[i])
	{
	  /* check  magic's next char */
	  i++;
	}
      else
	{
	  /* mismatch... game over... same player shoots again */
	  i = 0;
	  
	  /* maybe the current char matches magic's first char... */
	  if(c == magic[i])
	    {
	      /* check  magic's  next char */
	      i++;
	    }
	}
    }
  return;
}

