/**
 * \file
 * \brief RS-232 SCOP Transport module (SCOP Interface)
 */

/* TODO: error checking */

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fcntl.h>   
#include <termios.h> /* POSIX terminal control definitions */

#include <err.h>
#include <errno.h>

#include "scop.h"

/** \brief rs232 device descriptor */
int scop_rs232_device;

int scopTransportInit()
{

#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  /* open device */
  scop_rs232_device = open(SCOP_RS232_DEVICE, O_RDWR | O_NOCTTY | O_NDELAY);
  if (scop_rs232_device == -1)
    {
      warnx("%s(): %s %s", __FUNCTION__, "Unable to open ", SCOP_RS232_DEVICE);
    }
  else
    {
      /* clear all flags */
      fcntl(scop_rs232_device, F_SETFL, 0);
    }

  return 0;
}

void scopTransportRead(char * buffer, int len)
{
  int i;
  int result;

#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  /* get bytes one by one from the device */
  for(i=0; i<len; i++)
    {
      while( (result=read(scop_rs232_device, &buffer[i], 1)) != 1)
	{
#ifdef __Freebsd__
	  /* check if the line is down */
	  result = write(scop_rs232_device, "", 0);
	  if( (result==-1) && (errno==EIO))
	    {
	      /* reset connection */
	      close(scop_rs232_device);
	      scopTransportInit();
	    }
#endif /* __Freebsd__ */
	}
    }

  return;
}

void scopTransportSend(char * buffer, int len)
{
#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  /* send message through the socket */
  write(scop_rs232_device, buffer, len);

  /* append end-of-message magic byte (0x00) */
  write(scop_rs232_device, "", 1);
  
  return;
}

void scopTransportSynchro(char * magic)
{
  int i, result;
  char c;

#ifdef TRACE
  DEBUG_indent += 2;
  for(DEBUG_i=0; DEBUG_i<(DEBUG_indent-2); DEBUG_i+=2, printf("| "));
  printf("|-TRACE: %s()\n",__FUNCTION__);
#endif

  for(i=0; i<strlen(magic);)
    {
      /* read next char */
      while( (result=read(scop_rs232_device, &c, 1)) != 1)	
	{
#ifdef __Freebsd__
	  /* check if the line is down */
	  result = write(scop_rs232_device, "", 0);
	  if( (result==-1) && (errno==EIO))
	    {
	      /* reset connection */
	      close(scop_rs232_device);
	      scopTransportInit();
	    }
#endif /* __Freebsd__ */
	}
      
      /* check if this char matches magic's current char */
      if(c == magic[i])
	{
	  /* check  magic's next char */
	  i++;
	}
      else
	{
	  /* mismatch... game over... same player shoots again */
	  i = 0;
	  
	  /* maybe the current char matches magic's first char... */
	  if(c == magic[i])
	    {
	      /* check  magic's  next char */
	      i++;
	    }
	}
    }
  return;
}

