/*
 * ----------------------------------------------------------------------------
 *  (C) Copyright Testing Technologies, 2001-2007.  All Rights Reserved.
 *
 *  All copies of this program, whether in whole or in part, and whether
 *  modified or not, must display this and all other embedded copyright
 *  and ownership notices in full.
 *
 *  See the file COPYRIGHT for details of redistribution and use.
 *
 *  You should have received a copy of the COPYRIGHT file along with
 *  this file; if not, write to the Testing Technologies,
 *  Rosenthaler Str. 13, 10119 Berlin, Germany.
 *
 *  TESTING TECHNOLOGIES DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 *  SOFTWARE. IN NO EVENT SHALL TESTING TECHNOLOGIES BE LIABLE FOR ANY
 *  SPECIAL, DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 *  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 *  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 *  THIS SOFTWARE.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
 *  EITHER EXPRESSED OR IMPLIED, INCLUDING ANY KIND OF IMPLIED OR
 *  EXPRESSED WARRANTY OF NON-INFRINGEMENT OR THE IMPLIED WARRANTIES
 *  OF MECHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * ----------------------------------------------------------------------------
 *
 *  AUTHOR:      Dirk Tepelmann
 *  DATE:        November, 2006
 *
 *  REVISION INFO:
 *        $Revision$ $Date$
 * ----------------------------------------------------------------------------- */
package com.testingtech.ttcn.tri;

import org.etsi.ttcn.tci.EnumeratedValue;
import org.etsi.ttcn.tci.RecordValue;

import de.tu_berlin.cs.uebb.ttcn.runtime.OctetString;

public class IKESecurityParameterInfo {
	private OctetString spiInitiator;
	private OctetString spiResponder;
//	private int messageID;
	private EnumeratedValue ikeEncryptionAlgo;
//	private OctetString ikeEncryptionKey;
	private int ikeEncryptionKeyLength;
	private int ikeEncrBlockSize;
	private EnumeratedValue ikeIntegrityAlgo;
//	private OctetString ikeIntegrityKey;
	private int ikeIntegrityKeyLength;
	private int ikeIcvLen;
	private EnumeratedValue ikePseudoRandomFunction;
	private int ikePRFKeyLength;
	private EnumeratedValue diffieHellmanGroup;
	private OctetString diffieHellmanPrivKey;
	private OctetString diffieHellmanSharedSecret;
	private RecordValue sevenSecrets;

	public IKESecurityParameterInfo(OctetString spiInitiator,
			OctetString spiResponder, 
//			int messageID,
			EnumeratedValue ikeEncryptionAlgo, 
//			OctetString ikeEncryptionKey,
			int ikeEncryptionKeyLength,
			int ikeEncrBlockSize,
			EnumeratedValue ikeIntegrityAlgo, 
//			OctetString ikeIntegrityKey,
			int ikeIntegrityKeyLength,
			int ikeIcvLen,
			EnumeratedValue ikePseudoRandomFunction,
			int ikePRFKeyLength,
			EnumeratedValue diffieHellmanGroup,
			OctetString diffieHellmanPrivKey,
			OctetString diffieHellmanSharedSecret, RecordValue sevenSecrets) {
		super();
		this.spiInitiator = spiInitiator;
		this.spiResponder = spiResponder;
//		this.messageID = messageID;
		this.ikeEncryptionAlgo = ikeEncryptionAlgo;
//		this.ikeEncryptionKey = ikeEncryptionKey;
		this.ikeEncryptionKeyLength =ikeEncryptionKeyLength;
		this.ikeEncrBlockSize = ikeEncrBlockSize;
		this.ikeIntegrityAlgo = ikeIntegrityAlgo;
//		this.ikeIntegrityKey = ikeIntegrityKey;
		this.ikeIntegrityKeyLength =ikeIntegrityKeyLength;
		this.ikeIcvLen = ikeIcvLen;
		this.ikePseudoRandomFunction = ikePseudoRandomFunction;
		this.ikePRFKeyLength =ikePRFKeyLength;
		this.diffieHellmanGroup = diffieHellmanGroup;
		this.diffieHellmanPrivKey = diffieHellmanPrivKey;
		this.diffieHellmanSharedSecret = diffieHellmanSharedSecret;
		this.sevenSecrets = sevenSecrets;
	}
//	/**
//	 * @return the messageID
//	 */
//	public int getMessageID() {
//		return messageID;
//	}
//	/**
//	 * @param messageID the messageID to set
//	 */
//	public void setMessageID(int messageID) {
//		this.messageID = messageID;
//	}
	/**
	 * @return the spiInitiator
	 */
	public OctetString getSpiInitiator() {
		return spiInitiator;
	}
	/**
	 * @param spiInitiator the spiInitiator to set
	 */
	public void setSpiInitiator(OctetString spiInitiator) {
		this.spiInitiator = spiInitiator;
	}
	/**
	 * @return the spiResponder
	 */
	public OctetString getSpiResponder() {
		return spiResponder;
	}
	/**
	 * @param spiResponder the spiResponder to set
	 */
	public void setSpiResponder(OctetString spiResponder) {
		this.spiResponder = spiResponder;
	}
	/**
	 * @return the diffieHellmanGroup
	 */
	public EnumeratedValue getDiffieHellmanGroup() {
		return diffieHellmanGroup;
	}
	/**
	 * @param diffieHellmanGroup the diffieHellmanGroup to set
	 */
	public void setDiffieHellmanGroup(EnumeratedValue diffieHellmanGroup) {
		this.diffieHellmanGroup = diffieHellmanGroup;
	}
	/**
	 * @return the diffieHellmanPrivKey
	 */
	public OctetString getDiffieHellmanPrivKey() {
		return diffieHellmanPrivKey;
	}
	/**
	 * @param diffieHellmanPrivKey the diffieHellmanPrivKey to set
	 */
	public void setDiffieHellmanPrivKey(OctetString diffieHellmanPrivKey) {
		this.diffieHellmanPrivKey = diffieHellmanPrivKey;
	}
	/**
	 * @return the diffieHellmanSharedSecret
	 */
	public OctetString getDiffieHellmanSharedSecret() {
		return diffieHellmanSharedSecret;
	}
	/**
	 * @param diffieHellmanSharedSecret the diffieHellmanSharedSecret to set
	 */
	public void setDiffieHellmanSharedSecret(OctetString diffieHellmanSharedSecret) {
		this.diffieHellmanSharedSecret = diffieHellmanSharedSecret;
	}
	/**
	 * @return the ikeEncryptionAlgo
	 */
	public EnumeratedValue getIkeEncryptionAlgo() {
		return ikeEncryptionAlgo;
	}
	/**
	 * @param ikeEncryptionAlgo the ikeEncryptionAlgo to set
	 */
	public void setIkeEncryptionAlgo(EnumeratedValue ikeEncryptionAlgo) {
		this.ikeEncryptionAlgo = ikeEncryptionAlgo;
	}
//	/**
//	 * @return the ikeEncryptionKey
//	 */
//	public OctetString getIkeEncryptionKey() {
//		return ikeEncryptionKey;
//	}
//	/**
//	 * @param ikeEncryptionKey the ikeEncryptionKey to set
//	 */
//	public void setIkeEncryptionKey(OctetString ikeEncryptionKey) {
//		this.ikeEncryptionKey = ikeEncryptionKey;
//	}
	/**
	 * @return the ikeEncryptionKeyLength
	 */
	public int getIkeEncryptionKeyLength() {
		return ikeEncryptionKeyLength;
	}
	/**
	 * @param ikeEncryptionKeyLength the ikeEncryptionKeyLength to set
	 */
	public void setIkeEncryptionKeyLength(int ikeEncryptionKeyLength) {
		this.ikeEncryptionKeyLength = ikeEncryptionKeyLength;
	}
	/**
	 * @return the ikeIcvLen
	 */
	public int getIkeIcvLen() {
		return ikeIcvLen;
	}
	/**
	 * @param ikeIcvLen the ikeIcvLen to set
	 */
	public void setIkeIcvLen(int ikeIcvLen) {
		this.ikeIcvLen = ikeIcvLen;
	}
	/**
	 * @return the ikeEncrBlockSize
	 */
	public int getIkeEncrBlockSize() {
		return ikeEncrBlockSize;
	}
	/**
	 * @param ikeEncrBlockSize the ikeEncrBlockSize to set
	 */
	public void setIkeEncrBlockSize(int ikeEncrBlockSize) {
		this.ikeEncrBlockSize = ikeEncrBlockSize;
	}
	/**
	 * @return the ikeIntegrityAlgo
	 */
	public EnumeratedValue getIkeIntegrityAlgo() {
		return ikeIntegrityAlgo;
	}
	/**
	 * @param ikeIntegrityAlgo the ikeIntegrityAlgo to set
	 */
	public void setIkeIntegrityAlgo(EnumeratedValue ikeIntegrityAlgo) {
		this.ikeIntegrityAlgo = ikeIntegrityAlgo;
	}
//	/**
//	 * @return the ikeIntegrityKey
//	 */
//	public OctetString getIkeIntegrityKey() {
//		return ikeIntegrityKey;
//	}
//	/**
//	 * @param ikeIntegrityKey the ikeIntegrityKey to set
//	 */
//	public void setIkeIntegrityKey(OctetString ikeIntegrityKey) {
//		this.ikeIntegrityKey = ikeIntegrityKey;
//	}
	/**
	 * @return the ikeIntegrityKeyLength
	 */
	public int getIkeIntegrityKeyLength() {
		return ikeIntegrityKeyLength;
	}
	/**
	 * @param ikeIntegrityKeyLength the ikeIntegrityKeyLength to set
	 */
	public void setIkeIntegrityKeyLength(int ikeIntegrityKeyLength) {
		this.ikeIntegrityKeyLength = ikeIntegrityKeyLength;
	}
	/**
	 * @return the ikePseudoRandomFunction
	 */
	public EnumeratedValue getIkePseudoRandomFunction() {
		return ikePseudoRandomFunction;
	}
	/**
	 * @param ikePseudoRandomFunction the ikePseudoRandomFunction to set
	 */
	public void setIkePseudoRandomFunction(EnumeratedValue ikePseudoRandomFunction) {
		this.ikePseudoRandomFunction = ikePseudoRandomFunction;
	}
	/**
	 * @return the ikePRFKeyLength
	 */
	public int getIkePRFKeyLength() {
		return ikePRFKeyLength;
	}
	/**
	 * @param ikeIntegrityKeyLength the ikeIntegrityKeyLength to set
	 */
	public void setIkePRFKeyLength(int ikePRFKeyLength) {
		this.ikePRFKeyLength = ikePRFKeyLength;
	}
	/**
	 * @return the sevenSecrets
	 */
	public RecordValue getSevenSecrets() {
		return sevenSecrets;
	}
	/**
	 * @param sevenSecrets the sevenSecrets to set
	 */
	public void setSevenSecrets(RecordValue sevenSecrets) {
		this.sevenSecrets = sevenSecrets;
	}
}
