/*
 * ----------------------------------------------------------------------------
 *  (C) Copyright Testing Technologies, 2001-2006.  All Rights Reserved.
 *
 *  All copies of this program, whether in whole or in part, and whether
 *  modified or not, must display this and all other embedded copyright
 *  and ownership notices in full.
 *
 *  See the file COPYRIGHT for details of redistribution and use.
 *
 *  You should have received a copy of the COPYRIGHT file along with
 *  this file; if not, write to the Testing Technologies,
 *  Rosenthaler Str. 13, 10119 Berlin, Germany.
 *
 *  TESTING TECHNOLOGIES DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 *  SOFTWARE. IN NO EVENT SHALL TESTING TECHNOLOGIES BE LIABLE FOR ANY
 *  SPECIAL, DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 *  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 *  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 *  THIS SOFTWARE.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
 *  EITHER EXPRESSED OR IMPLIED, INCLUDING ANY KIND OF IMPLIED OR
 *  EXPRESSED WARRANTY OF NON-INFRINGEMENT OR THE IMPLIED WARRANTIES
 *  OF MECHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * ----------------------------------------------------------------------------
 *
 *  AUTHOR:      Dirk Tepelmann
 *  DATE:        September, 2006
 *
 *  REVISION INFO:
 *        $Revision$ $Date$
 * ----------------------------------------------------------------------------- */
package com.testingtech.ttcn.tri;

import java.math.BigInteger;

import org.etsi.ttcn.tci.EnumeratedValue;

import de.tu_berlin.cs.uebb.ttcn.runtime.OctetString;

public class SecurityParameterInfo {
	private BigInteger spi;
	private int seqNr;
	private EnumeratedValue ahIntegrityAlgo;
	private OctetString	ahIntegrityKey;
	private int ahIcvLen;
	private EnumeratedValue espEncryptionAlgo;
	private OctetString	espEncryptionKey;
	private OctetString espIv;
	private int espEncrBlockSize;
	private EnumeratedValue espIntegrityAlgo;
	private OctetString	espIntegrityKey;
	private int espIcvLen;
//	private EnumeratedValue espCombinedModeAlgo;
//	private OctetString	espCombinedModeKey;
	private EnumeratedValue ipSecProtocolMode;

	public SecurityParameterInfo(BigInteger spi, int seqNr,
			EnumeratedValue ahIntegrityAlgo, OctetString ahIntegrityKey,
			int ahIcvLen,
			EnumeratedValue espEncryptionAlgo, OctetString espEncryptionKey, OctetString espIv,
			int espEncrBlockSize,
			EnumeratedValue espIntegrityAlgo, OctetString espIntegrityKey,
			int espIcvLen,
//			EnumeratedValue espCombinedModeAlgo, OctetString espCombinedModeKey, 
			EnumeratedValue ipSecProtocolMode) {
		super();
		this.spi = spi;
		this.seqNr = seqNr;
		this.ahIntegrityAlgo = ahIntegrityAlgo;
		this.ahIntegrityKey = ahIntegrityKey;
		this.ahIcvLen = ahIcvLen;
		this.espEncryptionAlgo = espEncryptionAlgo;
		this.espEncryptionKey = espEncryptionKey;
		this.espIv = espIv;
		this.espEncrBlockSize = espEncrBlockSize;
		this.espIntegrityAlgo = espIntegrityAlgo;
		this.espIntegrityKey = espIntegrityKey;
		this.espIcvLen = espIcvLen;
//		this.espCombinedModeAlgo = espCombinedModeAlgo;
//		this.espCombinedModeKey = espCombinedModeKey;
		this.ipSecProtocolMode = ipSecProtocolMode;
	}

	/**
	 * @return Returns the ahIntegrityAlgo.
	 */
	public EnumeratedValue getAhIntegrityAlgo() {
		return ahIntegrityAlgo;
	}

	/**
	 * @param ahIntegrityAlgo The ahIntegrityAlgo to set.
	 */
	public void setAhIntegrityAlgo(EnumeratedValue ahIntegrityAlgo) {
		this.ahIntegrityAlgo = ahIntegrityAlgo;
	}

	/**
	 * @return Returns the ahIntegrityKey.
	 */
	public OctetString getAhIntegrityKey() {
		return ahIntegrityKey;
	}

	/**
	 * @param ahIntegrityKey The ahIntegrityKey to set.
	 */
	public void setAhIntegrityKey(OctetString ahIntegrityKey) {
		this.ahIntegrityKey = ahIntegrityKey;
	}

	/**
	 * @param ahIcvLen The ahIcvLen to set.
	 */
	public void setAhIcvLen(int ahIcvLen) {
		this.ahIcvLen = ahIcvLen;
	}

	/**
	 * @return Returns the ahIcvLen.
	 */
	public int getAhIcvLen() {
		return ahIcvLen;
	}

//	/**
//	 * @return Returns the espCombinedModeAlgo.
//	 */
//	public EnumeratedValue getEspCombinedModeAlgo() {
//		return espCombinedModeAlgo;
//	}
//
//	/**
//	 * @param espCombinedModeAlgo The espCombinedModeAlgo to set.
//	 */
//	public void setEspCombinedModeAlgo(EnumeratedValue espCombinedModeAlgo) {
//		this.espCombinedModeAlgo = espCombinedModeAlgo;
//	}
//
//	/**
//	 * @return Returns the espCombinedModeKey.
//	 */
//	public OctetString getEspCombinedModeKey() {
//		return espCombinedModeKey;
//	}
//
//	/**
//	 * @param espCombinedModeKey The espCombinedModeKey to set.
//	 */
//	public void setEspCombinedModeKey(OctetString espCombinedModeKey) {
//		this.espCombinedModeKey = espCombinedModeKey;
//	}

	/**
	 * @return Returns the espEncryptionAlgo.
	 */
	public EnumeratedValue getEspEncryptionAlgo() {
		return espEncryptionAlgo;
	}

	/**
	 * @param espEncryptionAlgo The espEncryptionAlgo to set.
	 */
	public void setEspEncryptionAlgo(EnumeratedValue espEncryptionAlgo) {
		this.espEncryptionAlgo = espEncryptionAlgo;
	}

	/**
	 * @return Returns the espEncryptionKey.
	 */
	public OctetString getEspEncryptionKey() {
		return espEncryptionKey;
	}

	/**
	 * @param espEncryptionKey The espEncryptionKey to set.
	 */
	public void setEspEncryptionKey(OctetString espEncryptionKey) {
		this.espEncryptionKey = espEncryptionKey;
	}

	/**
	 * @return Returns the espEncrBlockSize.
	 */
	public int getEspEncrBlockSize() {
		return espEncrBlockSize;
	}

	/**
	 * @param espEncrBlockSize The espEncrBlockSize to set.
	 */
	public void setEspEncrBlockSize(int espEncrBlockSize) {
		this.espEncrBlockSize = espEncrBlockSize;
	}

	/**
	 * @return Returns the espIv.
	 */
	public OctetString getEspIv() {
		return espIv;
	}

	/**
	 * @param espIv The espIv to set.
	 */
	public void setEspIv(OctetString espIv) {
		this.espIv = espIv;
	}

	/**
	 * @return Returns the espIntegrityAlgo.
	 */
	public EnumeratedValue getEspIntegrityAlgo() {
		return espIntegrityAlgo;
	}

	/**
	 * @param espIntegrityAlgo The espIntegrityAlgo to set.
	 */
	public void setEspIntegrityAlgo(EnumeratedValue espIntegrityAlgo) {
		this.espIntegrityAlgo = espIntegrityAlgo;
	}

	/**
	 * @return Returns the espIntegrityKey.
	 */
	public OctetString getEspIntegrityKey() {
		return espIntegrityKey;
	}

	/**
	 * @param espIntegrityKey The espIntegrityKey to set.
	 */
	public void setEspIntegrityKey(OctetString espIntegrityKey) {
		this.espIntegrityKey = espIntegrityKey;
	}

	/**
	 * @param espIcvLen The espIcvLen to set.
	 */
	public void setEspIcvLen(int icvLen) {
		this.espIcvLen = icvLen;
	}

	/**
	 * @return Returns the espIcvLen.
	 */
	public int getEspIcvLen() {
		return espIcvLen;
	}

	/**
	 * @return Returns the ipSecProtocolMode.
	 */
	public EnumeratedValue getIpSecProtocolMode() {
		return ipSecProtocolMode;
	}

	/**
	 * @param ipSecProtocolMode The ipSecProtocolMode to set.
	 */
	public void setIpSecProtocolMode(EnumeratedValue ipSecProtocolMode) {
		this.ipSecProtocolMode = ipSecProtocolMode;
	}

	/**
	 * @return Returns the seqNr.
	 */
	public int getSeqNr() {
		return seqNr;
	}

	/**
	 * @param seqNr The seqNr to set.
	 */
	public void setSeqNr(int seqNr) {
		this.seqNr = seqNr;
	}

	/**
	 * @return Returns the spi.
	 */
	public BigInteger getSpi() {
		return spi;
	}

	/**
	 * @param spi The spi to set.
	 */
	public void setSpi(BigInteger spi) {
		this.spi = spi;
	}		

}
