/*
 * ----------------------------------------------------------------------------
 *  (C) Copyright Testing Technologies, 2001-2007.  All Rights Reserved.
 *
 *  All copies of this program, whether in whole or in part, and whether
 *  modified or not, must display this and all other embedded copyright
 *  and ownership notices in full.
 *
 *  See the file COPYRIGHT for details of redistribution and use.
 *
 *  You should have received a copy of the COPYRIGHT file along with
 *  this file; if not, write to the Testing Technologies,
 *  Rosenthaler Str. 13, 10119 Berlin, Germany.
 *
 *  TESTING TECHNOLOGIES DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 *  SOFTWARE. IN NO EVENT SHALL TESTING TECHNOLOGIES BE LIABLE FOR ANY
 *  SPECIAL, DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 *  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 *  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 *  THIS SOFTWARE.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
 *  EITHER EXPRESSED OR IMPLIED, INCLUDING ANY KIND OF IMPLIED OR
 *  EXPRESSED WARRANTY OF NON-INFRINGEMENT OR THE IMPLIED WARRANTIES
 *  OF MECHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * ----------------------------------------------------------------------------
 *
 *  AUTHOR:      Dirk Tepelmann
 *  DATE:        September, 2006
 *
 *  REVISION INFO:
 *        $Revision$ $Date$
 * ----------------------------------------------------------------------------- */
package com.testingtech.ttcn.tri.encrypt;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.Mac;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;

import org.etsi.ttcn.tci.OctetstringValue;

import com.testingtech.ttcn.logging.RTLoggingConstants;
import com.testingtech.ttcn.tri.enums.IEnumDefinitions;
import com.testingtech.util.HexViewer;

import de.tu_berlin.cs.uebb.muttcn.runtime.RB;
import de.tu_berlin.cs.uebb.ttcn.runtime.OctetString;

public class Encryption implements IEnumDefinitions {

	/**
	 * @param rb
	 * @param algo
	 * @param p_key
	 * @param p_message
	 * @param bitLen
	 * @return
	 */
	public static OctetstringValue getEncryptHMACx(RB rb, String algo, OctetstringValue p_key, OctetstringValue p_message, int bitLen) {
		OctetString o = new OctetString(rb);

		if (algo.startsWith("Hmac")) {
			try {
				Mac m = Mac.getInstance(algo);
				SecretKey sk = new SecretKeySpec(((OctetString)p_key).toByteArray(), algo);
				m.init(sk);
				byte[] doFinal = m.doFinal(((OctetString)p_message).toByteArray());
				o.setOctetstring(doFinal);
				if (bitLen>0) {
					if (o.getLength()>(bitLen/8)) {
						o = ((OctetString)o).shiftRight(o.getLength()-(bitLen/8));
						o.setLength((bitLen/8));
					}
				}
			} catch (NoSuchAlgorithmException e) {
				rb.tciTMProvided.tciError(e.getMessage());
			} catch (InvalidKeyException e) {
				rb.tciTMProvided.tciError(e.getMessage());
			}
		}
		else {
			rb.getTciTLProvided().tliRT(null, System.nanoTime(), null, 0, null, RTLoggingConstants.RT_LOG_ERROR, "getEncryptHMACx: invalid algorithm " + algo + "!");
		}
		
		return o;
	}
	
	/**
	 * @param rb
	 * @param p_message
	 * @param bitLen
	 * @return
	 */
	public static OctetstringValue getSHA1Integrity(RB rb, OctetstringValue p_message, int bitLen) {
		OctetString o = new OctetString(rb);

		try {
			MessageDigest md = MessageDigest.getInstance("SHA-1");
			o.setOctetstring(md.digest(((OctetString)p_message).toByteArray()));
			if (bitLen>0) {
				if (o.getLength()>(bitLen/8)) {
					o = ((OctetString)o).shiftRight(o.getLength()-(bitLen/8));
					o.setLength((bitLen/8));
				}
			}
		} catch (NoSuchAlgorithmException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		}
		
		return o;
	}
	
	/**
	 * @param rb TODO
	 * @param p_algo
	 * @param p_keyAlgo
	 * @param p_key
	 * @param p_message
	 * @return
	 */
//	public static byte [] getEncryptedString(RB rb, String p_algo, String p_keyAlgo, byte [] p_key, byte [] p_message, byte [] p_iv) {
	public static byte [] getEncryptedString(RB rb, String p_algo, String p_keyAlgo, byte [] p_key, byte [] p_message, ByteArrayOutputStream p_iv) {
		byte [] doFinal = null;

		p_algo = mapEncAlgorithm(p_algo);
		
		try {
			Cipher c = Cipher.getInstance(p_algo);
			SecretKey sk = new SecretKeySpec(p_key, p_keyAlgo);
			if (p_iv.size()>0 ) {
				c.init(Cipher.ENCRYPT_MODE, sk, new IvParameterSpec(p_iv.toByteArray()));
			}
			else {
				c.init(Cipher.ENCRYPT_MODE, sk);
				System.out.println("getEncryptedString: No IV specified! Using " + HexViewer.hexString(c.getIV()));
				p_iv.write(c.getIV());
			}
			doFinal = c.doFinal(p_message);
		} catch (NoSuchAlgorithmException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (NoSuchPaddingException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (InvalidKeyException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (IllegalBlockSizeException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (BadPaddingException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (InvalidAlgorithmParameterException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (IOException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		}
		
		return doFinal;
	}
	
	/**
	 * @param rb TODO
	 * @param p_algo
	 * @param p_keyAlgo
	 * @param p_key
	 * @param p_message
	 * @param p_iv
	 * @return
	 */
	public static byte [] getDecryptedString(RB rb, String p_algo, String p_keyAlgo, byte [] p_key, byte [] p_message, byte[] p_iv) {
		byte [] doFinal = null;

		p_algo = mapEncAlgorithm(p_algo);
		
		try {
			Cipher c = Cipher.getInstance(p_algo);
			SecretKey sk = new SecretKeySpec(p_key, p_keyAlgo);
			if (p_iv != null ) {
				c.init(Cipher.DECRYPT_MODE, sk, new IvParameterSpec(p_iv));
			}
			else {
				System.err.println("ERROR: no IV specified!");
				return null;
			}
			doFinal = c.doFinal(p_message);
		} catch (NoSuchAlgorithmException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (NoSuchPaddingException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (InvalidKeyException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (IllegalBlockSizeException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (BadPaddingException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		} catch (InvalidAlgorithmParameterException e) {
			rb.tciTMProvided.tciError(e.getMessage());
		}
		
		return doFinal;
	}
	
	/**
	 * @param algo
	 * @return
	 */
	public static String mapEncAlgorithm(String algo) {
		if (algo.equals(ENCRYPTION_E_TRIPLEDES_CBC)) {
			return "TripleDES/CBC/NoPadding";
		}
		else if (algo.equals(ENCRYPTION_E_AES_CBC)) {
			return "AES/CBC/NoPadding";
		}
		else if (algo.equals(ENCRYPTION_E_AES_CTR)) {
			return "AES/CTR/NoPadding";
		}
		else if (algo.equals(ENCRYPTION_E_DES_CBC)) {
			return "DES/CBC/NoPadding";
		}
		System.err.println("Could not map encryption algorithm: " + algo + "!");
		return algo;
	}
}
